@@ -1,22 +1,21 @@
-import csv, unittest
+"""Tests for Zawgyi detector module."""
+
+import csv
 from importlib.resources import open_text
+import unittest
+
 from myanmartools import ZawgyiDetector
 
+
 class TestZawgyiDetector(unittest.TestCase):
-    '''
-    Tests the ZawgyiDetector class.
-    '''
+    """Test for ZawgyiDetector class."""
+
     def setUp(self):
-        '''
-        Creates a ZawgyiDetector object for testing.
-        '''
+        """Create a ZawgyiDetector instance."""
         self.detector = ZawgyiDetector()
 
     def test_strong(self):
-        '''
-        Tests a Unicode string which should produce a very low score
-        and a Zawgyi string which should produce a very high score.
-        '''
+        """Test a Unicode string and a Zawgyi string."""
         strong_unicode = 'အပြည်ပြည်ဆိုင်ရာ လူ့အခွင့်အရေး ကြေညာစာတမ်း'
         strong_zawgyi = 'အျပည္ျပည္ဆိုင္ရာ လူ႔အခြင့္အေရး ေၾကညာစာတမ္း'
         self.assertLess(
@@ -29,16 +28,10 @@ class TestZawgyiDetector(unittest.TestCase):
         )
 
     def test_compatibility(self):
-        '''
-        Compares results with those obtained from Java version of the
-        detector. They should be the same, within float tolerances.
-        '''
+        """Compare results with Java results."""
         with open_text('myanmartools.resources', 'compatibility.tsv') as f:
             for row in csv.reader(f, delimiter='\t'):
                 self.assertAlmostEqual(
                     self.detector.get_zawgyi_probability(row[1]),
                     float(row[0])
                 )
-
-if __name__ == '__main__':
-    unittest.main()
